@@ -28,6 +28,7 @@ char *s = N_("Add new movie");
 char *s = N_("All Movies");
 char *s = N_("Attempt to fetch a big poster from Amazon services Web site");
 char *s = N_("By Collection");
+char *s = N_("By Tag");
 char *s = N_("By Volume");
 char *s = N_("Cast");
 char *s = N_("Choose Image");
@@ -77,6 +78,7 @@ char *s = N_("Loan Management");
 char *s = N_("Loan movie");
 char *s = N_("Loan to");
 char *s = N_("Loaned Movies");
+char *s = N_("Loaned to");
 char *s = N_("Loans");
 char *s = N_("Main list");
 char *s = N_("Manage People");
