@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: add.py 891 2007-12-16 21:13:53Z piotrek $'
+__revision__ = '$Id: add.py 962 2008-07-18 15:19:29Z mikej06 $'
 
 # Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski
 #
@@ -587,15 +587,24 @@ def get_from_web(self):
 		self.search_movie = plugin.SearchPlugin()
 		if o_title:
 			self.search_movie.url = self.search_movie.original_url_search
-			self.search_movie.title = gutils.remove_accents(o_title, 'utf-8')
+			if self.search_movie.remove_accents:
+				self.search_movie.title = gutils.remove_accents(o_title, 'utf-8')
+			else:
+				self.search_movie.title = unicode(o_title, 'utf-8')
 		elif title:
 			self.search_movie.url = self.search_movie.translated_url_search
-			self.search_movie.title = gutils.remove_accents(title, 'utf-8')
+			if self.search_movie.remove_accents:
+				self.search_movie.title = gutils.remove_accents(title, 'utf-8')
+			else:
+				self.search_movie.title = unicode(title, 'utf-8')
 		self.search_movie.search(self.widgets['add']['window'])
 		self.search_movie.get_searches()
 		if len(self.search_movie.ids) == 1 and o_title and title:
 			self.search_movie.url = self.search_movie.translated_url_search
-			self.search_movie.title = gutils.remove_accents(title, 'utf-8')
+			if self.search_movie.remove_accents:
+				self.search_movie.title = gutils.remove_accents(title, 'utf-8')
+			else:
+				self.search_movie.title = unicode(title, 'utf-8')
 			self.search_movie.search(self.widgets['add']['window'])
 			self.search_movie.get_searches()
 		self.show_search_results(self.search_movie)
