@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: initialize.py 891 2007-12-16 21:13:53Z piotrek $'
+__revision__ = '$Id: initialize.py 966 2008-07-24 20:42:36Z mikej06 $'
 
 # Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski
 #
@@ -47,7 +47,7 @@ def locations(self):
 	locations['exec'] = os.path.abspath(os.path.dirname(sys.argv[0])) # deprecated
 	locations['lib']  = os.path.dirname(__file__)
 	
-	if os.name == 'nt' or os.name == 'win32':
+	if os.name == 'nt' or os.name.startswith('win'): # win32, win64
 		import winshell
 		from win32com.shell import shellcon, shell
 		import shutil
@@ -144,7 +144,7 @@ def location_posters(locations, config):
 def gui(self):
 	self._ = None
 	self.debug.show("running on %s - %s" % (os.name, platform.system()))
-	if os.name == 'win32' or os.name == 'nt':
+	if os.name == 'nt' or os.name.startswith('win'):
 		self.windows = True
 	else:
 		self.windows = False
@@ -248,6 +248,15 @@ def treeview(self):
 	self.runtime_column.set_alignment(1)
 	self.runtime_column.set_reorderable(True)
 	self.widgets['treeview'].append_column(self.runtime_column)
+	# rating column
+	renderer=gtk.CellRendererText()
+	renderer.set_property('xalign', 0.5)
+	self.rating_column=gtk.TreeViewColumn(_('Rating'), renderer, text=9)
+	self.rating_column.set_sort_column_id(9)
+	self.rating_column.set_resizable(True)
+	self.rating_column.set_alignment(0.5)
+	self.rating_column.set_reorderable(True)
+	self.widgets['treeview'].append_column(self.rating_column)
 	# reflect saved column order
 	columnorder = self.config.get('columnorder', None, section='mainlist')
 	if not columnorder is None:
@@ -281,6 +290,9 @@ def treeview(self):
 			elif col == 'runtime':
 				self.widgets['treeview'].move_column_after(self.runtime_column, currentcol)
 				currentcol = self.runtime_column
+			elif col == 'rating':
+				self.widgets['treeview'].move_column_after(self.rating_column, currentcol)
+				currentcol = self.rating_column
 	# add data to treeview
 	self.total = int(self.db.Movie.count())
 	self.widgets['treeview'].show()
@@ -569,8 +581,12 @@ def dictionaries(self):
 	self.am_tags = {} # dictionary for tag CheckBoxes
 	update.update_volume_combo_ids(self)
 	update.update_collection_combo_ids(self)
+	update.update_loanedto_combo_ids(self)
+	update.update_bytag_combo_ids(self)
 	fill_volumes_combo(self)
 	fill_collections_combo(self)
+	fill_loanedto_combo(self)
+	fill_bytag_combo(self)
 	fill_preferences_tags_combo(self)
 	language_combos(self)
 	acodec_combos(self)
@@ -703,8 +719,9 @@ def fill_volumes_combo(self, default=0):
 			name = self.db.Volume.get_by(volume_id=vol_id).name
 		else:
 			name = ''
-		self.widgets['add']['volume'].insert_text(int(i), str(name))
-		self.widgets['filter']['volume'].insert_text(int(i), str(name))
+		# add some white spaces to prevent scrollbar hides parts of the names	
+		self.widgets['add']['volume'].insert_text(int(i), str(name) + '   ')
+		self.widgets['filter']['volume'].insert_text(int(i), str(name) + '   ')
 	self.widgets['add']['volume'].show_all()
 	self.widgets['filter']['volume'].show_all()
 	self.widgets['filter']['volume'].set_active(0)
@@ -722,8 +739,9 @@ def fill_collections_combo(self, default=0):
 			name = self.db.Collection.get_by(collection_id=col_id).name
 		else:
 			name = ''
-		self.widgets['add']['collection'].insert_text(int(i), str(name))
-		self.widgets['filter']['collection'].insert_text(int(i), str(name))
+		# add some white spaces to prevent scrollbar hides parts of the names	
+		self.widgets['add']['collection'].insert_text(int(i), str(name) + '   ')
+		self.widgets['filter']['collection'].insert_text(int(i), str(name) + '   ')
 	self.widgets['add']['collection'].show_all()
 	self.widgets['filter']['collection'].show_all()
 	self.widgets['filter']['collection'].set_active(0)
@@ -732,6 +750,32 @@ def fill_collections_combo(self, default=0):
 		self.widgets['add']['collection'].set_active(int(i))
 	self.widgets['add']['collection'].set_wrap_width(2)
 
+def fill_loanedto_combo(self):
+	self.widgets['filter']['loanedto'].get_model().clear()
+	for i in self.loanedto_combo_ids:
+		per_id = self.loanedto_combo_ids[i]
+		if per_id>0:
+			name = self.db.Person.get_by(person_id=per_id).name
+		else:
+			name = ''
+		# add some white spaces to prevent scrollbar hides parts of the names	
+		self.widgets['filter']['loanedto'].insert_text(int(i), str(name) + '   ')
+	self.widgets['filter']['loanedto'].show_all()
+	self.widgets['filter']['loanedto'].set_active(0)
+
+def fill_bytag_combo(self):
+	self.widgets['filter']['tag'].get_model().clear()
+	for i in self.bytag_combo_ids:
+		id = self.bytag_combo_ids[i]
+		if id>0:
+			name = self.db.Tag.get_by(tag_id=id).name
+		else:
+			name = ''
+		# add some white spaces to prevent scrollbar hides parts of the names	
+		self.widgets['filter']['tag'].insert_text(int(i), str(name) + '   ')
+	self.widgets['filter']['tag'].show_all()
+	self.widgets['filter']['tag'].set_active(0)
+
 def fill_preferences_tags_combo(self):
 	self.widgets['preferences']['tag_name'].get_model().clear()
 	self.tags_ids = {}
