@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: main_treeview.py 891 2007-12-16 21:13:53Z piotrek $'
+__revision__ = '$Id: main_treeview.py 967 2008-07-25 10:02:27Z mikej06 $'
 
 # Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski
 
@@ -241,6 +241,7 @@ def set_details(self, item=None):#{{{
 			self.person_name = str(data_person.name)
 			self.person_email = str(data_person.email)
 			self.loan_date = str(data_loan.date)
+			w['loan_info'].set_use_markup(False)
 			w['loan_info'].set_label(_("This movie has been loaned to ") + self.person_name + _(" on ") + self.loan_date[:10])
 	if item.has_key('loaned') and item['loaned'] != True: # "loaned" status can be changed above, so don't use "else:" in this line
 		self.widgets['popups']['loan'].set_sensitive(True)
@@ -343,7 +344,8 @@ def populate(self, movies=None, where=None):#{{{
 			self.db.Movie.c.o_title, self.db.Movie.c.title,
 			self.db.Movie.c.director, self.db.Movie.c.image,
 			self.db.Movie.c.genre, self.db.Movie.c.seen,
-			self.db.Movie.c.year, self.db.Movie.c.runtime])
+			self.db.Movie.c.year, self.db.Movie.c.runtime,
+			self.db.Movie.c.rating])
 
 	if isinstance(movies, Select):
 		if not where: # because of possible 'seen', 'loaned', 'collection_id' in where
@@ -366,6 +368,28 @@ def populate(self, movies=None, where=None):#{{{
 				vol_id = self.volume_combo_ids[pos]
 				if vol_id > 0:
 					movies.append_whereclause(self.db.Movie.c.volume_id==vol_id)
+			# loaned to
+			pos = self.widgets['filter']['loanedto'].get_active()
+			if pos >= 0:
+				per_id = self.loanedto_combo_ids[pos]
+				if per_id > 0:
+					from sqlalchemy import join, exists, and_
+					loan_exists = exists([self.db.Loan.c.movie_id], \
+						and_(self.db.Movie.c.movie_id==self.db.Loan.c.movie_id, self.db.Loan.c.person_id==per_id, self.db.Loan.c.return_date==None))
+					movies.append_whereclause(loan_exists)
+					#loan_join = join(self.db.metadata.tables['movies'], \
+					#	self.db.metadata.tables['loans'], \
+					#	self.db.metadata.tables['movies'].c.movie_id==self.db.metadata.tables['loans'].c.movie_id)
+					#movies = movies.select_from(loan_join)
+			# tag
+			pos = self.widgets['filter']['tag'].get_active()
+			if pos >= 0:
+				tag_id = self.bytag_combo_ids[pos]
+				if tag_id > 0:
+					from sqlalchemy import join, exists, and_
+					tag_exists = exists([self.db.MovieTag.c.movie_id], \
+						and_(self.db.Movie.c.movie_id==self.db.MovieTag.c.movie_id, self.db.MovieTag.c.tag_id==tag_id))
+					movies.append_whereclause(tag_exists)
 		
 		# select sort column
 		sort_column_name = self.config.get('sortby', 'number', section='mainlist')
@@ -393,7 +417,7 @@ def populate(self, movies=None, where=None):#{{{
 	sort_column_id, order = self.treemodel.get_sort_column_id()
 
 	# new treemodel (faster and prevents some problems)
-	self.treemodel = gtk.TreeStore(str, gtk.gdk.Pixbuf, str, str, str, str, bool, str, str)
+	self.treemodel = gtk.TreeStore(str, gtk.gdk.Pixbuf, str, str, str, str, bool, str, str, int)
 
 	# check preferences to hide or show columns
 	if self.config.get('number', True, 'mainlist') == True:
@@ -432,6 +456,10 @@ def populate(self, movies=None, where=None):#{{{
 		self.runtime_column.set_visible(True)
 	else:
 		self.runtime_column.set_visible(False)
+	if self.config.get('rating', True, 'mainlist') == True:
+		self.rating_column.set_visible(True)
+	else:
+		self.rating_column.set_visible(False)
 		
 	for movie in movies:
 		myiter = self.treemodel.append(None)
@@ -464,9 +492,12 @@ def populate(self, movies=None, where=None):#{{{
 		self.treemodel.set_value(myiter,4,movie.director)
 		self.treemodel.set_value(myiter,5,movie.genre)
 		self.treemodel.set_value(myiter,6,movie.seen)
-		self.treemodel.set_value(myiter,7,movie.year)
-		if movie.runtime is not None:
+		if movie.year is not None and movie.year is int:
+			self.treemodel.set_value(myiter,7,movie.year)
+		if movie.runtime is not None and movie.runtime is int:
 			self.treemodel.set_value(myiter,8, '%003d' % movie.runtime + _(' min'))
+		if movie.rating is not None and movie.rating is int:
+			self.treemodel.set_value(myiter,9,movie.rating)
 		
 	# restore user sort column
 	if sort_column_id is not None:
