@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: movie.py 891 2007-12-16 21:13:53Z piotrek $'
+__revision__ = '$Id: movie.py 962 2008-07-18 15:19:29Z mikej06 $'
 
 # Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski
 #
@@ -225,6 +225,7 @@ class SearchMovie:
 	translated_url_search = None
 	elements = None
 	title = None
+	remove_accents = True
 
 	def __init__(self):
 		pass
@@ -290,6 +291,22 @@ class Retriever(threading.Thread):
 				downloaded_kbyte = int(count * blockSize/1024.0)
 				filesize_kbyte = int(totalSize/1024.0)
 
+#
+# use own derived URLopener class because we need to set a correct User-Agent
+# string for some web sites. The default is 'Python-urllib/<version>'
+# which not all sites accepting. (zelluloid.de for example)
+#
+_uaurlopener = None
+def urlretrieve(url, filename=None, reporthook=None, data=None):
+    global _uaurlopener
+    if not _uaurlopener:
+        _uaurlopener = UAFancyURLopener()
+    return _uaurlopener.retrieve(url, filename, reporthook, data)
+
+class UAFancyURLopener(FancyURLopener):
+	# use Firefox 3.0 User-Agent string from Windows XP
+	version = 'Mozilla/5.0 (Windows; U; Windows NT 6.0) Gecko/2008052906 Firefox/3.0'
+	
 class Progress:
 	def __init__(self, window, title, message):
 		self.status = False
