@@ -1,7 +1,7 @@
 # -*- coding: UTF-8 -*-
 # vim: fdm=marker
 
-__revision__ = '$Id: PluginExportHTML.py 891 2007-12-16 21:13:53Z piotrek $'
+__revision__ = '$Id: PluginExportHTML.py 963 2008-07-21 20:03:51Z piotrek $'
 
 # Copyright (c) 2005-2007 Piotr Ożarowski
 #
@@ -588,12 +588,13 @@ class ExportPlugin(gtk.Window):
 		
 		# sort order	TODO: more than one sort column
 		sort_columns = []
+		sorting_parts = config['sorting'].split('_')
 		if config['sorting2'] == 'ASC':
 			from sqlalchemy import asc
-			sort_columns.append(asc(self.db.Movie.c[self.fields_as_columns[config['sorting']]]))
+			sort_columns.append(asc(self.db.metadata.tables[sorting_parts[0]].c['_'.join(sorting_parts[1:])]))
 		elif config['sorting2'] == 'DESC':
 			from sqlalchemy import desc
-			sort_columns.append(desc(self.db.Movie.c[self.fields_as_columns[config['sorting']]]))
+			sort_columns.append(desc(self.db.metadata.tables[sorting_parts[0]].c['_'.join(sorting_parts[1:])]))
 
 		statement = select(columns=columns, order_by=sort_columns, from_obj=[media_join, collection_join, volume_join, vcodec_join], use_labels = True)
 
@@ -767,6 +768,12 @@ class ExportPlugin(gtk.Window):
 			else:
 				tpl_header = self.fill_template(tpl_header, self.names[j], remove=True)
 
+		# check if line break needs conversion
+		if tpl_header.upper().find('XHTML 1.0') > -1:
+			linebreak_replacement = '<br />'
+		else:
+			linebreak_replacement = None
+
 		item=1	# item's position on page (1 - first, ...)
 		i = 1
 		page=1	# page number
@@ -804,10 +811,18 @@ class ExportPlugin(gtk.Window):
 						tmp = self.fill_template(tmp, self.names[j], _('No'), j)
 					else:
 						try:
-							tmp = self.fill_template(tmp, self.names[j], str(row[self.names[j]]).encode('utf-8'), j)
+							data = str(row[self.names[j]]).encode('utf-8')
+							if linebreak_replacement is not None:
+								data = data.replace('\r\n', linebreak_replacement)
+								data = data.replace('\n', linebreak_replacement)
+							tmp = self.fill_template(tmp, self.names[j], data, j)
 						except UnicodeDecodeError:
 							self.debug.show("Unicode Decode Error occurred while decoding %s (movie number: %s)" % (self.names[j], row['movies_number']))
-							tmp = self.fill_template(tmp, self.names[j], str(row[self.names[j]]), j)
+							data = str(row[self.names[j]])
+							if linebreak_replacement is not None:
+								data = data.replace('\r\n', linebreak_replacement)
+								data = data.replace('\n', linebreak_replacement)
+							tmp = self.fill_template(tmp, self.names[j], data, j)
 						except Exception, ex:
 							self.debug.show("Error occurred while decoding %s (movie number: %s)" % (self.names[j], row['movies_number']))
 				else:
