@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: preferences.py 891 2007-12-16 21:13:53Z piotrek $'
+__revision__ = '$Id: preferences.py 958 2008-07-17 21:01:21Z mikej06 $'
 
 # Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski
 #
@@ -80,6 +80,11 @@ def show_preferences(self):
 		w['view_runtime'].set_active(False)
 	else:
 		w['view_runtime'].set_active(True)
+	# rating
+	if self.config.get('rating', True, 'mainlist') == False:
+		w['view_rating'].set_active(False)
+	else:
+		w['view_rating'].set_active(True)
 
 	# email reminder
 	if self.config.get('use_auth', False, section='mail') == False:
@@ -174,6 +179,7 @@ def show_preferences(self):
 		w['spellchecker'].set_active(False)
 	else:
 		w['spellchecker'].set_active(True)
+	self.on_cb_spellchecker_pref_toggled(w['spellchecker'])
 
 	if self.config.get('notes', True, section='spell') == False:
 		w['spell_notes'].set_active(False)
@@ -252,6 +258,11 @@ def save_preferences(self):
 		c.set('runtime', 'True', section='mainlist')
 	else:
 		c.set('runtime', 'False', section='mainlist')
+	# rating
+	if w['view_rating'].get_active():
+		c.set('rating', 'True', section='mainlist')
+	else:
+		c.set('rating', 'False', section='mainlist')
 	
 	# sortby
 	if w['sortby'].get_active():
