@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: update.py 891 2007-12-16 21:13:53Z piotrek $'
+__revision__ = '$Id: update.py 951 2008-07-11 18:52:03Z mikej06 $'
 
 # Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski
 #
@@ -22,22 +22,42 @@ __revision__ = '$Id: update.py 891 2007-12-16 21:13:53Z piotrek $'
 # GNU General Public License, version 2 or later
 
 from gettext import gettext as _
+from sqlalchemy import Select, desc
 import gutils
 import os
 
 def update_volume_combo_ids(self):
-	self.volume_combo_ids = {}
-	self.volume_combo_ids[0] = 0
-	i = 1
-	for volume in self.db.Volume.select():
-		self.volume_combo_ids[i] = volume.volume_id
-		i += 1
+    self.volume_combo_ids = {}
+    self.volume_combo_ids[0] = 0
+    i = 1
+    volumes = Select(self.db.Volume.c, order_by='name')
+    for volume in volumes.execute().fetchall():
+        self.volume_combo_ids[i] = volume.volume_id
+        i += 1
 
 def update_collection_combo_ids(self):
 	self.collection_combo_ids = {}
 	self.collection_combo_ids[0] = 0
 	i = 1
-	for collection in self.db.Collection.select():
+	collections = Select(self.db.Collection.c, order_by='name')
+	for collection in collections.execute().fetchall():
 		self.collection_combo_ids[i] = collection.collection_id
 		i += 1
 
+def update_loanedto_combo_ids(self):
+	self.loanedto_combo_ids = {}
+	self.loanedto_combo_ids[0] = 0
+	i = 1
+	persons = Select(self.db.Person.c, order_by='name')
+	for person in persons.execute().fetchall():
+		self.loanedto_combo_ids[i] = person.person_id
+		i += 1
+
+def update_bytag_combo_ids(self):
+	self.bytag_combo_ids = {}
+	self.bytag_combo_ids[0] = 0
+	i = 1
+	tags = Select(self.db.Tag.c, order_by='name')
+	for tag in tags.execute().fetchall():
+		self.bytag_combo_ids[i] = tag.tag_id
+		i += 1
