@@ -1,8 +1,8 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: version.py 827 2007-08-05 18:41:38Z piotrek $'
+__revision__ = '$Id: version.py 968 2008-07-26 20:17:42Z piotrek $'
 
-# Copyright (c) 2005-2007 Vasco Nunes, Piotr Ożarowski
+# Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,8 +23,8 @@ __revision__ = '$Id: version.py 827 2007-08-05 18:41:38Z piotrek $'
 
 from gettext import gettext as _
 pname        = "Griffith"
-pversion     = "0.9.4"
+pversion     = "0.9.7.1"
 pauthor      = "Vasco Nunes, Piotr Ożarowski <griffith-private@lists.berlios.de>"
-pyear        = "2005-2007"
-pwebsite     = "http://griffith.berlios.de/"
+pyear        = "2005-2008"
+pwebsite     = "http://www.griffith.cc/"
 pdescription = _("Griffith is a film collection manager.")
