@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: widgets.py 891 2007-12-16 21:13:53Z piotrek $'
+__revision__ = '$Id: widgets.py 958 2008-07-17 21:01:21Z mikej06 $'
 
 # Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski
 #
@@ -138,6 +138,8 @@ def define_widgets(self, gladefile):
 	}
 	self.widgets['add']['window'].connect('delete_event', self.on_delete_event_am)
 	self.widgets['add']['lang_treeview'].connect('button_press_event', self.on_lang_treeview_button_press_event)
+	self.widgets['add']['o_title'].connect('activate', self.on_enter)
+	self.widgets['add']['title'].connect('activate', self.on_enter)
 	self.widgets['add']['window'].set_transient_for(self.widgets['window'])
 	#}}}
 
@@ -186,6 +188,7 @@ def define_widgets(self, gladefile):
 		'view_seen':	get('view_seen'),
 		'view_year':	get('view_year'),
 		'view_runtime':	get('view_runtime'),
+		'view_rating':	get('view_rating'),
 		'rating_image':		get('rating_image'),
 		'spellchecker':		get('spellchecker_pref'),
 		'spell_notes':		get('spell_notes'),
@@ -277,6 +280,8 @@ def define_widgets(self, gladefile):
 		'criteria':	get('filter_criteria'),
 		'collection':	get('f_col'),
 		'volume':	get('f_volume'),
+		'loanedto':	get('f_loanedto'),
+		'tag':	get('f_bytag'),
 	}#}}}
 	
 	self.widgets['menu'] = {#{{{
@@ -418,6 +423,8 @@ def define_widgets(self, gladefile):
 		'on_am_remove_collection_button_clicked': self.remove_collection,
 		'on_f_col_changed'			: self.filter_collection,
 		'on_f_volume_changed'			: self.filter_volume,
+		'on_f_loanedto_changed'			: self.filter_loanedto,
+		'on_f_bytag_changed'			: self.filter_bytag,
 		'on_results_cancel_clicked'		: self.results_cancel_ck,
 		# languages
 		'on_lang_add_clicked'			: self.on_lang_add_clicked,
