@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-__revision__ = '$Id: winsetup.py 891 2007-12-16 21:13:53Z piotrek $'
+__revision__ = '$Id: winsetup.py 968 2008-07-26 20:17:42Z piotrek $'
 
 # Copyright (c) 2005-2007 Vasco Nunes
 # This program is free software; you can redistribute it and/or modify
@@ -54,11 +54,11 @@ opts = {
 
 setup(
     name = "Griffith",
-    version = "0.9.6",
+    version = "0.9.7.1",
 	description = 'Griffith - A film manager',
     author = 'Vasco Nunes/Piotr Ozarowski',
     author_email = 'vasco.m.nunes@gmail.com',
-    url = 'http://griffith.berlios.de',
+    url = 'http://griffith.cc/',
     license = 'GPL',
     windows = [
         {
